pub struct ZvecError {
pub code: ErrorCode,
pub message: Option<String>,
}Expand description
Error returned by fallible safe wrappers over the zvec C API.
The message field, when present, is the last-error message retrieved via
sys::zvec_get_last_error at the time the error was constructed.
Fields
code: ErrorCodemessage: Option<String>Implementations
Sourceimpl ZvecError
impl ZvecError
Sourcepub fn from_code(code: Type) -> Self
pub fn from_code(code: Type) -> Self
Construct an error from a raw code, pulling the current thread-local message out of the C API if one is set.
Sourcepub fn with_message(code: ErrorCode, message: impl Into<String>) -> Self
pub fn with_message(code: ErrorCode, message: impl Into<String>) -> Self
Construct an error with a static message (used for cases where the C
API did not provide a detailed message, e.g. NULL-returning creators).